@@ -600,7 +600,7 @@ int mutt_prepare_template (FILE *fp, CONTEXT *ctx, HEADER *newhdr, HEADER *hdr,
 
   /* parse the message header and MIME structure */
 
-  fseeko (fp, hdr->offset, 0);
+  fseeko (fp, hdr->offset, SEEK_SET);
   newhdr->offset = hdr->offset;
   /* enable header weeding for resent messages */
   newhdr->env = mutt_read_rfc822_header (fp, newhdr, 1, resend);
