@@ -20,5 +20,4 @@
  */
 
 void rfc2231_decode_parameters (PARAMETER **);
-int rfc2231_encode_string (char **);
-
+PARAMETER *rfc2231_encode_string (const char *, char *);
